@@ -1,10 +1,10 @@
 import logging
 from collections import defaultdict
 from enum import Enum
-from itertools import groupby
+from itertools import groupby, chain
 from typing import Type, cast, List, Optional, Dict
 
-from collections_extended import RangeMap
+from collections_extended import RangeMap, MappedRange
 from log_with_context import add_logging_context, Logger
 from pydantic import BaseModel, Field
 from pymultirole_plugins.v1.processor import ProcessorParameters, ProcessorBase
@@ -27,6 +27,9 @@ class AFPEntitiesParameters(ProcessorParameters):
     <li>**unknown** to retain all but prepending the `unknown_prefix` to the label of unknown entities<br />""",
     )
     kill_label: Optional[str] = Field("kill", description="Label name of the kill list")
+    eurovoc_label: Optional[str] = Field(
+        "eurovoc", description="Label name of the Eurovoc thesaurus"
+    )
 
 
 class AFPEntitiesProcessor(ProcessorBase):
@@ -57,25 +60,43 @@ class AFPEntitiesProcessor(ProcessorBase):
         return AFPEntitiesParameters
 
 
+EUROVOC_NS = "http://eurovoc.europa.eu/"
+
+
 def compute_fingerprint(ann_groups):
+    def get_sort_key(r: MappedRange):
+        return -r.start, r.stop - r.start
+
     fingerprints = []
-    for wiki_r in ann_groups["wikidata"].ranges():
-        wiki_ann = wiki_r.value
-        if wiki_ann.terms and len(wiki_ann.terms):
-            fingerprints.append(wiki_ann.terms[0].identifier)
-            fingerprint = wiki_ann.terms[0].properties.get("fingerprint", None)
-            if fingerprint:
-                props_vals = [
-                    (p, v)
-                    for p, v in [
-                        pv.split(":", maxsplit=1) for pv in fingerprint.split(",")
+    sorted_ann = sorted(
+        chain(ann_groups["wikidata"].ranges(), ann_groups["eurovoc"].ranges()),
+        key=get_sort_key,
+        reverse=True,
+    )
+    for r in sorted_ann:
+        ann = r.value
+        if ann.terms and len(ann.terms):
+            if ann.terms[0].lexicon == "wikidata":
+                fingerprints.append(ann.terms[0].identifier)
+                fingerprint = ann.terms[0].properties.get("fingerprint", None)
+                if fingerprint:
+                    props_vals = [
+                        (p, v)
+                        for p, v in [
+                            pv.split(":", maxsplit=1) for pv in fingerprint.split(",")
+                        ]
                     ]
-                ]
-                wiki_ann.terms[0].properties["fingerprint"] = props_vals
-                try:
-                    fingerprints.extend([v for p, v in props_vals if v.startswith("Q")])
-                except BaseException:
-                    logging.exception()
+                    ann.terms[0].properties["fingerprint"] = props_vals
+                    try:
+                        fingerprints.extend(
+                            [v for p, v in props_vals if v.startswith("Q")]
+                        )
+                    except BaseException:
+                        logging.exception()
+            elif ann.terms[0].lexicon == "eurovoc" and ann.terms[
+                0
+            ].identifier.startswith(EUROVOC_NS):
+                fingerprints.append("E" + ann.terms[0].identifier[len(EUROVOC_NS) :])
     return fingerprints
 
 
