@@ -30,6 +30,17 @@ def original_doc():
         return original_doc
 
 
+# Arrange
+@pytest.fixture
+def original_doc_en():
+    testdir = Path(__file__).parent
+    source = Path(testdir, "data/afp_ner_en-document-test.json")
+    with source.open("r") as fin:
+        doc = json.load(fin)
+        original_doc = Document(**doc)
+        return original_doc
+
+
 def by_linking(a: Annotation):
     if a.terms:
         links = sorted({t.lexicon.split("_")[0] for t in a.terms})
@@ -47,7 +58,7 @@ def test_afp_entities_linker(original_doc):
     conso: Document = docs[0]
     assert conso.altTexts == HasLen(1)
     altText = conso.altTexts[0]
-    FINGERPRINT = re.compile(r"(Q\d+[ ]?)+")
+    FINGERPRINT = re.compile(r"([QE]\d+[ ]?)+")
     assert altText.dict() == IsPartialDict(
         name="fingerprint", text=IsStr(regex=FINGERPRINT)
     )
@@ -92,7 +103,7 @@ def test_afp_entities_whitelist():
     conso: Document = docs[0]
     assert conso.altTexts == HasLen(1)
     altText = conso.altTexts[0]
-    FINGERPRINT = re.compile(r"(Q\d+[ ]?)+")
+    FINGERPRINT = re.compile(r"([QE]\d+[ ]?)+")
     assert altText.dict() == IsPartialDict(
         name="fingerprint", text=IsStr(regex=FINGERPRINT)
     )
@@ -120,3 +131,18 @@ def test_afp_entities_whitelist():
     )
     assert len(conso_groups["wikidata"]) == 1
     assert len(conso_groups["location"]) == 2
+
+
+def test_afp_entities_linker_en(original_doc_en):
+    # linker
+    doc = original_doc_en.copy(deep=True)
+    processor = AFPEntitiesProcessor()
+    parameters = AFPEntitiesParameters(type=ConsolidationType.linker)
+    docs = processor.process([doc], parameters)
+    conso: Document = docs[0]
+    assert conso.altTexts == HasLen(1)
+    altText = conso.altTexts[0]
+    FINGERPRINT = re.compile(r"([QE]\d+[ ]?)+")
+    assert altText.dict() == IsPartialDict(
+        name="fingerprint", text=IsStr(regex=FINGERPRINT)
+    )
